
---
# Current Limit 10 click

> PRVIH_PAR_RECENICA_SA_PRODUCT_PAGE_DA_ISPRATE_CELINU

<p align="center">
  <img src="CLICK_IMAGE_LINK" height=300px>
</p>

[click Product page](CLICK_PRODUCT_PAGE_LINK)

---


#### Click library

- **Author**        : Nenad Filipovic
- **Date**          : Oct 2023.
- **Type**          : I2C type


# Software Support

We provide a library for the Current Limit 10 Click
as well as a demo application (example), developed using MikroElektronika
[compilers](https://www.mikroe.com/necto-studio).
The demo can run on all the main MikroElektronika [development boards](https://www.mikroe.com/development-boards).

Package can be downloaded/installed directly from *NECTO Studio Package Manager*(recommended way), downloaded from our [LibStock&trade;](https://libstock.mikroe.com) or found on [Mikroe github account](https://github.com/MikroElektronika/mikrosdk_click_v2/tree/master/clicks).

## Library Description

> This library contains API for Current Limit 10 Click driver.

#### Standard key functions :

- `currentlimit10_cfg_setup` Config Object Initialization function.
```c
void currentlimit10_cfg_setup ( currentlimit10_cfg_t *cfg );
```

- `currentlimit10_init` Initialization function.
```c
err_t currentlimit10_init ( currentlimit10_t *ctx, currentlimit10_cfg_t *cfg );
```

- `currentlimit10_default_cfg` Click Default Configuration function.
```c
err_t currentlimit10_default_cfg ( currentlimit10_t *ctx );
```

#### Example key functions :

- `currentlimit10_set_limit` This function sets the desired current limit threshold using the I2C serial interface.
```c
err_t currentlimit10_set_limit ( currentlimit10_t *ctx, float current_limit );
```

- `currentlimit10_get_fault` This function gets the state of the fault flag to indicate overcurrent, overtemperature, or reverse-voltage conditions.
```c
uint8_t currentlimit10_get_fault ( currentlimit10_t *ctx );
```

- `currentlimit10_enable` This function turns on the power switch and enables the internal MOSFET.
```c
void currentlimit10_enable ( currentlimit10_t *ctx );
```

## Example Description

> This library contains API for the Current Limit 10 Click driver for the current limiting 
> to a certain value and displays the sources a current proportional to the load current [A].

**The demo application is composed of two sections :**

### Application Init

> Initialization of I2C module and log UART.
> After driver initialization, the app executes a default configuration.

```c
void application_init ( void ) 
{
    log_cfg_t log_cfg;  /**< Logger config object. */
    currentlimit10_cfg_t currentlimit10_cfg;  /**< Click config object. */

    /** 
     * Logger initialization.
     * Default baud rate: 115200
     * Default log level: LOG_LEVEL_DEBUG
     * @note If USB_UART_RX and USB_UART_TX 
     * are defined as HAL_PIN_NC, you will 
     * need to define them manually for log to work. 
     * See @b LOG_MAP_USB_UART macro definition for detailed explanation.
     */
    LOG_MAP_USB_UART( log_cfg );
    log_init( &logger, &log_cfg );
    log_info( &logger, " Application Init " );

    // Click initialization.
    currentlimit10_cfg_setup( &currentlimit10_cfg );
    CURRENTLIMIT10_MAP_MIKROBUS( currentlimit10_cfg, MIKROBUS_1 );
    if ( I2C_MASTER_ERROR == currentlimit10_init( &currentlimit10, &currentlimit10_cfg ) ) 
    {
        log_error( &logger, " Communication init." );
        for ( ; ; );
    }
    
    if ( CURRENTLIMIT10_ERROR == currentlimit10_default_cfg ( &currentlimit10 ) )
    {
        log_error( &logger, " Default configuration." );
        for ( ; ; );
    }
    
    log_info( &logger, " Application Task " );
    Delay_ms( 100 );
}
```

### Application Task

> This example demonstrates the use of the Current Limit 10 Click board. 
> The demo application sets the current limit threshold of 750 mA and 
> checks the fault flag for overcurrent conditions.

```c
void application_task ( void ) 
{
    if ( CURRENTLIMIT10_OK == currentlimit10_set_limit( &currentlimit10, 0.75 ) )
    {
        Delay_ms( 100 );
        if ( CURRENTLIMIT10_FAULT_FLAG == currentlimit10_get_fault( &currentlimit10 ) )
        {
            log_printf( &logger, "Fault flag: Overcurrent\r\n" );
            Delay_ms( 100 );
        }
        else
        {
            log_printf( &logger, " Current limit is 0.75 A\r\n" );
            Delay_ms( 100 );
        }
    }
    Delay_ms( 1000 );
}
```

The full application code, and ready to use projects can be installed directly from *NECTO Studio Package Manager*(recommended way), downloaded from our [LibStock&trade;](https://libstock.mikroe.com) or found on [Mikroe github account](https://github.com/MikroElektronika/mikrosdk_click_v2/tree/master/clicks).

**Other Mikroe Libraries used in the example:**

- MikroSDK.Board
- MikroSDK.Log
- Click.CurrentLimit10

**Additional notes and informations**

Depending on the development board you are using, you may need
[USB UART click](https://www.mikroe.com/usb-uart-click),
[USB UART 2 Click](https://www.mikroe.com/usb-uart-2-click) or
[RS232 Click](https://www.mikroe.com/rs232-click) to connect to your PC, for
development systems with no UART to USB interface available on the board. UART
terminal is available in all MikroElektronika
[compilers](https://shop.mikroe.com/compilers).

---
